@@ -83,6 +83,12 @@ XS(XS_Internals_PAR_BOOT) {
 #endif
     }
 
+    /* PAR::Packer isn't included in a packed executable, but we provide
+     * this scalar so that a packed script may refer to the version
+     * of PAR::Packer it was built with.
+     */
+    sv_setpv(get_sv("PAR::Packer::VERSION", GV_ADD), PAR_PACKER_VERSION);
+
     TAINT_NOT;
 
     /* create temporary PAR directory */
@@ -91,18 +97,11 @@ XS(XS_Internals_PAR_BOOT) {
         stmpdir = par_mktmpdir( fakeargv );
         if ( !stmpdir ) 
             croak("Unable to create cache directory");
-#ifndef WIN32
-        i = execvp(SvPV_nolen(GvSV(tmpgv)), fakeargv);
-        croak("%s: execution of %s failed (errno=%i)\n", 
-              fakeargv[0], SvPV_nolen(GvSV(tmpgv)), i);
-        return;
-#endif
     }
     i = PerlDir_mkdir(stmpdir, 0700);
     if ( (i != 0) && (i != EEXIST) && (i != -1) ) {
         croak("%s: creation of private cache subdirectory %s failed (errno=%i)\n", 
               fakeargv[0], stmpdir, i);
-        return;
     }
 }
 
